court\_scraper.platforms.oscn.parsers package
=============================================

Submodules
----------

court\_scraper.platforms.oscn.parsers.case\_detail module
---------------------------------------------------------

.. automodule:: court_scraper.platforms.oscn.parsers.case_detail
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: court_scraper.platforms.oscn.parsers
   :members:
   :undoc-members:
   :show-inheritance:
